@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009, 2012, 2013 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2012, 2013, 2014, 2015 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,19 +27,13 @@ int main(int argc, char** argv) {
 	QApplication app(argc, argv);
 	app.setApplicationName("Connectagram");
 	app.setApplicationVersion(VERSIONSTR);
+	app.setApplicationDisplayName(Window::tr("Connectagram"));
 	app.setOrganizationDomain("gottcode.org");
 	app.setOrganizationName("GottCode");
-	{
-		QIcon fallback(":/hicolor/256x256/apps/connectagram.png");
-		fallback.addFile(":/hicolor/128x128/apps/connectagram.png");
-		fallback.addFile(":/hicolor/64x64/apps/connectagram.png");
-		fallback.addFile(":/hicolor/48x48/apps/connectagram.png");
-		fallback.addFile(":/hicolor/32x32/apps/connectagram.png");
-		fallback.addFile(":/hicolor/24x24/apps/connectagram.png");
-		fallback.addFile(":/hicolor/22x22/apps/connectagram.png");
-		fallback.addFile(":/hicolor/16x16/apps/connectagram.png");
-		app.setWindowIcon(QIcon::fromTheme("connectagram", fallback));
-	}
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MAC)
+	app.setWindowIcon(QIcon::fromTheme("connectagram", QIcon(":/connectagram.png")));
+#endif
+	app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
 	QString path = app.applicationDirPath();
 	QStringList paths;
