@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009, 2013 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2013, 2014, 2015 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,8 +37,8 @@
 #include <QToolButton>
 #include <QVBoxLayout>
 
-#include <cstdlib>
 #include <ctime>
+#include <random>
 
 NewGameDialog::NewGameDialog(Board* board, QWidget* parent)
 : QDialog(parent, Qt::WindowTitleHint | Qt::WindowSystemMenuHint | Qt::WindowCloseButtonHint), m_board(board) {
@@ -49,7 +49,7 @@ NewGameDialog::NewGameDialog(Board* board, QWidget* parent)
 	m_wordlist->setLanguage(WordList::defaultLanguage());
 	m_languages_box = new QComboBox(this);
 	QStringList languages = QDir("connectagram:").entryList(QDir::Dirs | QDir::NoDotAndDotDot);
-	foreach (const QString& language, languages) {
+	for (const QString& language : languages) {
 		m_languages_box->addItem(LocaleDialog::languageName(language), language);
 	}
 
@@ -59,7 +59,7 @@ NewGameDialog::NewGameDialog(Board* board, QWidget* parent)
 
 	// Create word length box
 	m_word_length_box = new QComboBox(this);
-	connect(m_word_length_box, SIGNAL(activated(int)), this, SLOT(lengthSelected(int)));
+	connect(m_word_length_box, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &NewGameDialog::lengthSelected);
 
 	// Create pattern buttons
 	QFrame* patterns = new QFrame(this);
@@ -76,7 +76,7 @@ NewGameDialog::NewGameDialog(Board* board, QWidget* parent)
 		pattern_button->setIcon(QIcon(QString(":/patterns/%1.png").arg(i)));
 		pattern_button->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
 		pattern_button->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
-		connect(pattern_button, SIGNAL(clicked()), this, SLOT(patternSelected()));
+		connect(pattern_button, &QToolButton::clicked, this, &NewGameDialog::patternSelected);
 
 		patterns_layout->addWidget(pattern_button, i / 3, i % 3);
 		m_pattern_buttons.append(pattern_button);
@@ -84,7 +84,7 @@ NewGameDialog::NewGameDialog(Board* board, QWidget* parent)
 
 	// Create cancel button
 	QDialogButtonBox* buttons = new QDialogButtonBox(QDialogButtonBox::Cancel, Qt::Horizontal, this);
-	connect(buttons, SIGNAL(rejected()), this, SLOT(reject()));
+	connect(buttons, &QDialogButtonBox::rejected, this, &NewGameDialog::reject);
 
 	// Lay out dialog
 	QFormLayout* contents_layout = new QFormLayout;
@@ -108,7 +108,7 @@ NewGameDialog::NewGameDialog(Board* board, QWidget* parent)
 	setLength(settings.value("NewGame/Length", 7).toInt());
 	m_pattern_buttons.at(settings.value("NewGame/Pattern").toInt())->setFocus();
 
-	connect(m_languages_box, SIGNAL(currentIndexChanged(int)), this, SLOT(languageSelected(int)));
+	connect(m_languages_box, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &NewGameDialog::languageSelected);
 }
 
 //-----------------------------------------------------------------------------
@@ -121,7 +121,7 @@ NewGameDialog::~NewGameDialog() {
 
 void NewGameDialog::keyPressEvent(QKeyEvent* event) {
 	if ((event->key() == Qt::Key_Enter) || (event->key() == Qt::Key_Return)) {
-		foreach (QToolButton* button, m_pattern_buttons) {
+		for (QToolButton* button : m_pattern_buttons) {
 			if (button->hasFocus() && button->isEnabled()) {
 				button->click();
 				break;
@@ -171,8 +171,14 @@ void NewGameDialog::patternSelected() {
 	QString language = m_languages_box->itemData(m_languages_box->currentIndex()).toString();
 	int count = m_word_count_box->currentIndex();
 	int length = m_word_length_box->itemData(m_word_length_box->currentIndex()).toInt();
-	srand(time(0));
-	int seed = rand();
+#ifndef Q_OS_WIN
+	std::random_device rd;
+	unsigned int seed = rd();
+#else
+	std::mt19937 gen(time(0));
+	std::uniform_int_distribution<unsigned int> dist;
+	unsigned int seed = dist(gen);
+#endif
 
 	QSettings settings;
 	settings.remove("Current");
@@ -180,7 +186,7 @@ void NewGameDialog::patternSelected() {
 	settings.setValue("NewGame/Pattern", pattern);
 	settings.setValue("NewGame/Count", count);
 	settings.setValue("NewGame/Length", length);
-	settings.setValue("Current/Version", 3);
+	settings.setValue("Current/Version", 4);
 	settings.setValue("Current/Language", language);
 	settings.setValue("Current/Pattern", pattern);
 	settings.setValue("Current/Count", count);
