@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009, 2013 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2013, 2014 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 #ifndef PATTERN_H
 #define PATTERN_H
 
-#include "random.h"
 #include "wordlist.h"
 class Word;
 
@@ -32,6 +31,8 @@ class Word;
 #include <QStringList>
 #include <QThread>
 
+#include <random>
+
 class Pattern : public QThread {
 	Q_OBJECT
 
@@ -68,7 +69,7 @@ class Pattern : public QThread {
 			return m_solution;
 		}
 
-		int seed() const {
+		unsigned int seed() const {
 			return m_seed;
 		}
 
@@ -86,7 +87,7 @@ class Pattern : public QThread {
 
 		void setCount(int count);
 		void setLength(int length);
-		void setSeed(int seed);
+		void setSeed(unsigned int seed);
 
 	signals:
 		void generated();
@@ -99,7 +100,8 @@ class Pattern : public QThread {
 		virtual void run();
 
 		unsigned int randomInt(unsigned int max) {
-			return m_random.nextInt(max);
+			std::uniform_int_distribution<unsigned int> gen(0, max - 1);
+			return gen(m_random);
 		}
 
 	protected:
@@ -118,12 +120,12 @@ class Pattern : public QThread {
 		WordList* m_words;
 		int m_count;
 		int m_length;
-		int m_seed;
+		unsigned int m_seed;
 		QSize m_size;
 		QList<Word*> m_solution;
 		bool m_cancelled;
 		QMutex m_cancelled_mutex;
-		Random m_random;
+		std::mt19937 m_random;
 };
 
 //-----------------------------------------------------------------------------
