@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009, 2012 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2012, 2014 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,8 @@
 #include <QTreeWidget>
 #include <QVBoxLayout>
 
+#include <cmath>
+
 ScoreBoard::ScoreBoard(QWidget* parent)
 : QDialog(parent) {
 	setWindowTitle(tr("Scores"));
@@ -33,13 +35,8 @@ ScoreBoard::ScoreBoard(QWidget* parent)
 	// Create tree view
 	m_scores = new QTreeWidget(this);
 	m_scores->setHeaderLabels(QStringList() << tr("Score") << tr("Time") << tr("Words") << tr("Length"));
-#if (QT_VERSION >= QT_VERSION_CHECK(5,0,0))
 	m_scores->header()->setSectionsMovable(false);
 	m_scores->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
-#else
-	m_scores->header()->setMovable(false);
-	m_scores->header()->setResizeMode(QHeaderView::ResizeToContents);
-#endif
 	m_scores->header()->setStretchLastSection(false);
 	m_scores->setRootIsDecorated(false);
 
@@ -53,7 +50,7 @@ ScoreBoard::ScoreBoard(QWidget* parent)
 
 	// Create OK button
 	QDialogButtonBox* buttons = new QDialogButtonBox(QDialogButtonBox::Close, Qt::Horizontal, this);
-	connect(buttons, SIGNAL(rejected()), this, SLOT(reject()));
+	connect(buttons, &QDialogButtonBox::rejected, this, &ScoreBoard::reject);
 
 	// Layout window
 	QVBoxLayout* layout = new QVBoxLayout(this);
@@ -102,7 +99,7 @@ QTreeWidgetItem* ScoreBoard::createScoreItem(int secs, int count, int length) {
 	if (secs == 0) {
 		return 0;
 	}
-	int score = qRound((count * length * 120.0) / secs);
+	int score = std::lround((count * length * 120.0) / secs);
 	if (score == 0) {
 		return 0;
 	}
