@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009, 2012, 2013, 2014 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2012, 2013, 2014, 2015 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,13 +38,14 @@
 #include <QMessageBox>
 #include <QSettings>
 
-Window::Window() {
-	setWindowTitle(QCoreApplication::applicationName());
+#include <algorithm>
+#include <cmath>
 
+Window::Window() {
 	m_board = new Board(this);
-	connect(m_board, SIGNAL(finished()), this, SLOT(gameFinished()));
-	connect(m_board, SIGNAL(started()), this, SLOT(gameStarted()));
-	connect(m_board, SIGNAL(pauseChanged()), this, SLOT(gamePauseChanged()));
+	connect(m_board, &Board::finished, this, &Window::gameFinished);
+	connect(m_board, &Board::started, this, &Window::gameStarted);
+	connect(m_board, &Board::pauseChanged, this, &Window::gamePauseChanged);
 
 	QWidget* contents = new QWidget(this);
 	setCentralWidget(contents);
@@ -54,10 +55,10 @@ Window::Window() {
 	m_scores = new ScoreBoard(this);
 
 	m_definitions = new Definitions(m_board->words(), this);
-	connect(m_board, SIGNAL(wordAdded(QString)), m_definitions, SLOT(addWord(QString)));
-	connect(m_board, SIGNAL(wordSolved(QString, QString)), m_definitions, SLOT(solveWord(QString, QString)));
-	connect(m_board, SIGNAL(wordSelected(QString)), m_definitions, SLOT(selectWord(QString)));
-	connect(m_board, SIGNAL(loading()), m_definitions, SLOT(clear()));
+	connect(m_board, &Board::wordAdded, m_definitions, &Definitions::addWord);
+	connect(m_board, &Board::wordSolved, m_definitions, &Definitions::solveWord);
+	connect(m_board, &Board::wordSelected, m_definitions, &Definitions::selectWord);
+	connect(m_board, &Board::loading, m_definitions, &Definitions::clear);
 
 	// Create success message
 	m_success = new QLabel(contents);
@@ -85,7 +86,7 @@ Window::Window() {
 	}
 	m_success->setPixmap(pixmap);
 	m_success->hide();
-	connect(m_board, SIGNAL(loading()), m_success, SLOT(hide()));
+	connect(m_board, &Board::loading, m_success, &QLabel::hide);
 
 	// Create overlay background
 	QLabel* overlay = new QLabel(this);
@@ -93,14 +94,16 @@ Window::Window() {
 	f = font();
 	f.setPixelSize(20);
 	metrics = QFontMetrics(f);
-	width = qMax(metrics.width(tr("Loading")), metrics.width(tr("Paused")));
+	width = std::max(metrics.width(tr("Loading")), metrics.width(tr("Paused")));
 	for (int i = 0; i < 10; ++i) {
 		QString test(6, QChar(i + 48));
 		test.insert(4, QLatin1Char(':'));
 		test.insert(2, QLatin1Char(':'));
-		width = qMax(width, metrics.width(test));
+		width = std::max(width, metrics.width(test));
 	}
-	pixmap = QPixmap(QSize(width + 82, 32));
+	int ratio = devicePixelRatio();
+	pixmap = QPixmap(QSize(width + 82, 32) * ratio);
+	pixmap.setDevicePixelRatio(ratio);
 	pixmap.fill(Qt::transparent);
 	{
 		QPainter painter(&pixmap);
@@ -114,24 +117,24 @@ Window::Window() {
 
 	// Create overlay buttons
 	m_definitions_button = new QLabel(overlay);
-	m_definitions_button->setPixmap(QString(":/definitions.png"));
+	m_definitions_button->setPixmap(QIcon(":/definitions.png").pixmap(24,24));
 	m_definitions_button->setCursor(Qt::PointingHandCursor);
 	m_definitions_button->setToolTip(tr("Definitions"));
 	m_definitions_button->installEventFilter(this);
 
 	m_hint_button = new QLabel(overlay);
-	m_hint_button->setPixmap(QString(":/hint.png"));
+	m_hint_button->setPixmap(QIcon(":/hint.png").pixmap(24,24));
 	m_hint_button->setCursor(Qt::PointingHandCursor);
 	m_hint_button->setToolTip(tr("Hint"));
 	m_hint_button->setDisabled(true);
 	m_hint_button->installEventFilter(this);
-	connect(m_board, SIGNAL(hintAvailable(bool)), m_hint_button, SLOT(setEnabled(bool)));
+	connect(m_board, &Board::hintAvailable, m_hint_button, &QLabel::setEnabled);
 
 	// Create clock
 	m_clock = new Clock(overlay);
 	m_clock->setDisabled(true);
-	connect(m_clock, SIGNAL(togglePaused()), m_board, SLOT(togglePaused()));
-	connect(m_board, SIGNAL(loading()), m_clock, SLOT(setLoading()));
+	connect(m_clock, &Clock::togglePaused, m_board, &Board::togglePaused);
+	connect(m_board, &Board::loading, m_clock, &Clock::setLoading);
 
 	QHBoxLayout* overlay_layout = new QHBoxLayout(overlay);
 	overlay_layout->setMargin(0);
@@ -154,27 +157,30 @@ Window::Window() {
 
 	// Create menus
 	QMenu* menu = menuBar()->addMenu(tr("&Game"));
-	menu->addAction(tr("&New"), this, SLOT(newGame()), tr("Ctrl+N"));
+	menu->addAction(tr("&New"), this, SLOT(newGame()), QKeySequence::New);
 	menu->addAction(tr("&Choose..."), this, SLOT(chooseGame()));
 	menu->addSeparator();
 	m_pause_action = menu->addAction(tr("&Pause"), m_board, SLOT(togglePaused()), tr("P"));
 	m_pause_action->setDisabled(true);
-	QAction* hint_action = menu->addAction(tr("&Hint"), m_board, SLOT(showHint()), tr("H"));
-	hint_action->setDisabled(true);
-	connect(m_board, SIGNAL(hintAvailable(bool)), hint_action, SLOT(setEnabled(bool)));
+	QAction* action = menu->addAction(tr("&Hint"), m_board, SLOT(showHint()), tr("H"));
+	action->setDisabled(true);
+	connect(m_board, &Board::hintAvailable, action, &QAction::setEnabled);
 	menu->addAction(tr("D&efinitions"), m_definitions, SLOT(selectWord()), tr("D"));
 	menu->addSeparator();
 	menu->addAction(tr("&Details"), this, SLOT(showDetails()));
 	menu->addAction(tr("&Scores"), m_scores, SLOT(exec()));
 	menu->addSeparator();
-	menu->addAction(tr("&Quit"), qApp, SLOT(quit()), tr("Ctrl+Q"));
+	action = menu->addAction(tr("&Quit"), qApp, SLOT(quit()), QKeySequence::Quit);
+	action->setMenuRole(QAction::QuitRole);
 
 	menu = menuBar()->addMenu(tr("&Settings"));
 	menu->addAction(tr("Application &Language..."), this, SLOT(setLocale()));
 
 	menu = menuBar()->addMenu(tr("&Help"));
-	menu->addAction(tr("&About"), this, SLOT(about()));
-	menu->addAction(tr("About &Qt"), qApp, SLOT(aboutQt()));
+	action = menu->addAction(tr("&About"), this, SLOT(about()));
+	action->setMenuRole(QAction::AboutRole);
+	action = menu->addAction(tr("About &Qt"), qApp, SLOT(aboutQt()));
+	action->setMenuRole(QAction::AboutQtRole);
 
 	// Restore window geometry
 	QSettings settings;
@@ -183,7 +189,7 @@ Window::Window() {
 
 	// Continue previous or start new game
 	show();
-	if (settings.contains("Current/Words") && (settings.value("Current/Version" ).toInt() == 3)) {
+	if (settings.contains("Current/Words") && (settings.value("Current/Version" ).toInt() == 4)) {
 		m_board->openGame();
 	} else {
 		settings.remove("Current");
@@ -255,7 +261,7 @@ void Window::about() {
 	QMessageBox::about(this, tr("About"), QString("<p><center><big><b>%1 %2</b></big><br/>%3<br/><small>%4<br/>%5</small></center></p><p><center>%6</center></p>")
 		.arg(tr("Connectagram"), QCoreApplication::applicationVersion(),
 			tr("A word unscrambling game"),
-			tr("Copyright &copy; 2009-%1 by Graeme Gott").arg("2014"),
+			tr("Copyright &copy; 2009-%1 by Graeme Gott").arg("2015"),
 			tr("Released under the <a href=\"http://www.gnu.org/licenses/gpl.html\">GPL 3</a> license"),
 			tr("Definitions are from <a href=\"http://wiktionary.org/\">Wiktionary</a>"))
 	);
@@ -273,7 +279,7 @@ void Window::showDetails() {
 		<< NewGameDialog::tr("Medium")
 		<< NewGameDialog::tr("High")
 		<< NewGameDialog::tr("Very High");
-	QString number = "3"
+	QString number = "4"
 		+ m_board->words()->language()
 		+ patternid
 		+ QString::number(pattern->wordCount())
@@ -289,7 +295,7 @@ void Window::showDetails() {
 			.arg(tr("Game Number:")).arg(number),
 		QMessageBox::NoButton,
 		this);
-	dialog.setIconPixmap(QString(":/patterns/%1.png").arg(patternid));
+	dialog.setIconPixmap(QIcon(QString(":/patterns/%1.png").arg(patternid)).pixmap(96,96));
 	dialog.exec();
 }
 
@@ -322,7 +328,7 @@ void Window::gameFinished() {
 	m_pause_action->setDisabled(true);
 	m_success->show();
 
-	m_scores->addScore(qRound(msecs / 1000.0), count, length);
+	m_scores->addScore(std::lround(msecs / 1000.0), count, length);
 }
 
 //-----------------------------------------------------------------------------
